import{Q as u}from"./QPage-jfhvxjua.js";import{e as p,a as m}from"./axios-BxiOjpGq.js";import{u as _}from"./use-quasar-YIAhzlRm.js";import{L as f}from"./LineCharts-CNjvC0kh.js";import{aK as x,a as i,r as g,o as v,ab as o,a3 as r,a7 as y,as as l,aI as w,ao as C,a5 as P}from"./index-DA5wU65Q.js";import"./installCanvasRenderer-CfMBnVHW.js";const q={class:"col-12 q-pa-md"},L={__name:"PyPiCharts",setup(k){const a=_(),s=i(()=>a.screen.height*.73),c=i(()=>a.screen.width*.825),n=s.value,t=g({title:"",xAxis_list:[],series_list:[]});function h(){m({url:"core/pypi/charts/"}).then(e=>{t.value=e.pypi_data}).catch(e=>{a.notify({type:"error",message:e}),a.loading.hide()})}v(()=>{d(),h()});function d(){p.on("needLogin",e=>{e&&console.log("needLogin")})}return(e,B)=>(r(),o(u,{class:"flex flex-col q-pa-md"},{default:y(()=>[l("div",{class:"row full-width",style:w({height:`${s.value}px`})},[l("div",q,[t.value.series_list.length?(r(),o(f,{key:0,title:t.value.title,"x-axis-data":t.value.xAxis_list,"series-data":t.value.series_list,"show-legend":!0,"chart-height":P(n),"chart-width":c.value},null,8,["title","x-axis-data","series-data","chart-height","chart-width"])):C("",!0)])],4)]),_:1}))}},$=x(L,[["__scopeId","data-v-4da15453"]]);export{$ as default};
