import{Q as s}from"./QPage-jfhvxjua.js";import{u as n}from"./use-meta-B2AcZUiy.js";import{u as m,_ as c}from"./MDParser-C4xR3Qlp.js";import{r as e,o as i,e as p,ab as u,a3 as d,a7 as f,a6 as l}from"./index-DA5wU65Q.js";import"./rightDrawer-CNvQe7eg.js";import"./axios-BxiOjpGq.js";import"./_commonjsHelpers-Cpj98o6Y.js";import"./use-quasar-YIAhzlRm.js";import"./language-BAls7FvS.js";import"./vue-i18n.runtime-DQPK7Hwk.js";const Q={__name:"LocustReader",setup(_){const t=e(""),o=e(""),a=e(""),r=m();return n(()=>({title:t.value,meta:{description:{name:"description",content:o.value},keywords:{name:"keywords",content:a.value}}})),i(()=>{r.docNameChange("performance")}),p(()=>{}),(k,x)=>(d(),u(s,{class:"flex flex-top"},{default:f(()=>[l(c)]),_:1}))}};export{Q as default};
